| CompRiskRel-package | R Documentation |
Provides comprehensive tools for data generation, Maximum Likelihood Estimation (MLE), Bayesian estimation (Gibbs sampling, Metropolis-Hastings), Importance Sampling, Lindley approximation, stress-strength reliability estimation, optimal designs, and reliability acceptance sampling plans under Type-I, Type-II, and generalized (progressive) hybrid censoring schemes.
Maintainer: Shikhar Tyagi shikhar1093tyagi@gmail.com (ORCID)
Authors:
Arvind Pandey arvindmzu@gmail.com
Bhupendra Singh bhupendra.rana@gmail.com
Vrijesh Tripathi vrijesh.tripathi@uwi.edu
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.