mle_type1_hybrid: Maximum Likelihood Estimation under Type-I Hybrid Censoring

View source: R/mle_est.R

mle_type1_hybridR Documentation

Maximum Likelihood Estimation under Type-I Hybrid Censoring

Description

Maximum Likelihood Estimation under Type-I Hybrid Censoring

Usage

mle_type1_hybrid(
  data,
  pdf,
  cdf,
  init_par,
  method = "BFGS",
  lower = -Inf,
  upper = Inf
)

Arguments

data

Object of class comp_risk_rel_data or list with observed_times, censor_status, termination_time, and total sample size n.

pdf

Parametric probability density function of time x and vector parameter theta.

cdf

Parametric cumulative distribution function of time x and vector parameter theta.

init_par

Initial parameter vector for numerical optimization.

method

Maximization routine: "NR", "BFGS", "BFGSR", "BHHH", "SANN", "CG", or "NM".

lower

Lower bound for parameter vector.

upper

Upper bound for parameter vector.

Value

S3 object of class mle_fit with parameter estimates, log-likelihood, SE, and information criteria.

Examples

dat <- gen_type1_hybrid(
  pdf = function(x) dexp(x, rate = 1),
  cdf = function(x) pexp(x, rate = 1),
  lower = 0, upper = 10, n = 20, r = 10,
  T_star = 1.5, seed = 123
)
mle_type1_hybrid(
  data = dat,
  pdf = function(x, theta) dexp(x, rate = theta[1]),
  cdf = function(x, theta) pexp(x, rate = theta[1]),
  init_par = c(0.8), method = "BFGS"
)

CompRiskRel documentation built on Aug. 5, 2026, 9:08 a.m.