| mle_type1_hybrid | R Documentation |
Maximum Likelihood Estimation under Type-I Hybrid Censoring
mle_type1_hybrid(
data,
pdf,
cdf,
init_par,
method = "BFGS",
lower = -Inf,
upper = Inf
)
data |
Object of class |
pdf |
Parametric probability density function of time x and vector parameter theta. |
cdf |
Parametric cumulative distribution function of time x and vector parameter theta. |
init_par |
Initial parameter vector for numerical optimization. |
method |
Maximization routine: "NR", "BFGS", "BFGSR", "BHHH", "SANN", "CG", or "NM". |
lower |
Lower bound for parameter vector. |
upper |
Upper bound for parameter vector. |
S3 object of class mle_fit with parameter estimates, log-likelihood, SE, and information criteria.
dat <- gen_type1_hybrid(
pdf = function(x) dexp(x, rate = 1),
cdf = function(x) pexp(x, rate = 1),
lower = 0, upper = 10, n = 20, r = 10,
T_star = 1.5, seed = 123
)
mle_type1_hybrid(
data = dat,
pdf = function(x, theta) dexp(x, rate = theta[1]),
cdf = function(x, theta) pexp(x, rate = theta[1]),
init_par = c(0.8), method = "BFGS"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.